require 'awesome_print'
require 'csv'
require 'logger'
require 'nokogiri'
require 'open-uri'
# require 'pry-byebug'

require 'my_representatives/version.rb'
require "my_representatives/abbreviatable.rb"
require "my_representatives/fileable.rb"
require "my_representatives/guessable.rb"
require "my_representatives/hashable.rb"
require 'my_representatives/errors.rb'
require 'my_representatives/static.rb'
require 'my_representatives/electorate.rb'
require 'my_representatives/person.rb'

require 'my_representatives/act/csv_lower.rb'
require 'my_representatives/act/merge_lower.rb'
require 'my_representatives/act/web_index.rb'
require 'my_representatives/act/web_index_row.rb'
require 'my_representatives/act/web_lower.rb'
require 'my_representatives/act/web_show.rb'
require 'my_representatives/commonwealth/commonwealth.rb'
require 'my_representatives/commonwealth/csv_email.rb'
require 'my_representatives/commonwealth/csv_lower.rb'
require 'my_representatives/commonwealth/csv_upper.rb'
require 'my_representatives/commonwealth/merge_lower.rb'
require 'my_representatives/commonwealth/merge_upper.rb'
require 'my_representatives/commonwealth/web_index.rb'
require 'my_representatives/commonwealth/web_lower.rb'
require 'my_representatives/commonwealth/web_show.rb'
require 'my_representatives/commonwealth/web_upper.rb'
require 'my_representatives/nsw/csv_lower.rb'
require 'my_representatives/nsw/csv_upper.rb'
require 'my_representatives/nsw/merge_lower.rb'
require 'my_representatives/nsw/merge_upper.rb'
require 'my_representatives/nsw/web_index.rb'
require 'my_representatives/nsw/web_lower.rb'
require 'my_representatives/nsw/web_show.rb'
require 'my_representatives/nsw/web_upper.rb'
require 'my_representatives/nt/web_index.rb'
require 'my_representatives/nt/web_lower.rb'
require 'my_representatives/nt/web_show.rb'
require 'my_representatives/qld/csv_lower.rb'
require 'my_representatives/qld/merge_lower.rb'
require 'my_representatives/qld/web_index.rb'
require 'my_representatives/qld/web_lower.rb'
require 'my_representatives/qld/web_show.rb'
require 'my_representatives/sa/csv_lower.rb'
require 'my_representatives/sa/csv_upper.rb'
require 'my_representatives/sa/merge_lower.rb'
require 'my_representatives/sa/merge_upper.rb'
require 'my_representatives/sa/web_index_lower.rb'
require 'my_representatives/sa/web_index_upper.rb'
require 'my_representatives/sa/web_lower.rb'
require 'my_representatives/sa/web_show.rb'
require 'my_representatives/sa/web_upper.rb'
require 'my_representatives/tas/csv_lower.rb'
require 'my_representatives/tas/csv_upper.rb'
require 'my_representatives/vic/csv_lower.rb'
require 'my_representatives/vic/csv_upper.rb'
require 'my_representatives/vic/merge_lower.rb'
require 'my_representatives/vic/merge_upper.rb'
require 'my_representatives/vic/web_index.rb'
require 'my_representatives/vic/web_lower.rb'
require 'my_representatives/vic/web_show.rb'
require 'my_representatives/vic/web_upper.rb'
require 'my_representatives/wa/csv_lower.rb'
require 'my_representatives/wa/csv_upper.rb'
require 'my_representatives/wa/merge_lower.rb'
require 'my_representatives/wa/merge_upper.rb'
require 'my_representatives/wa/web_index.rb'
require 'my_representatives/wa/web_lower.rb'
require 'my_representatives/wa/web_show.rb'
require 'my_representatives/wa/web_upper.rb'

#Dir['my_representatives/**/*.rb'].each{ |f| require f }

module MyRepresentatives


  def self.new
    people = []

    ### Commonwealth
    puts "Fetching Commonwealth House of Representatives ..."
    Commonwealth::MergeLower.new.people.each { |p| people << p }
    puts "Fetching Commonwealth Senate ..."
    Commonwealth::MergeUpper.new.people.each { |p| people << p }

    ### Australian Capital Territory
    puts "Fetching ACT Lower House ..."
    ACT::MergeLower.new.people.each { |p| people << p }

    ### New South Wales
    puts "Fetching NSW Lower House ..."
    NSW::MergeLower.new.people.each { |p| people << p }
    puts "Fetching NSW Upper House ..."
    NSW::MergeUpper.new.people.each { |p| people << p }

    ### Northern Territory
    puts "Fetching NT Lower House ..."
    NT::WebLower.new.people.each { |p| people << p }

    ### Queensland
    puts "Fetching QLD Lower House ..."
    QLD::MergeLower.new.people.each { |p| people << p }

    ### South Australia
    puts "Fetching SA Lower House ..."
    SA::MergeLower.new.people.each { |p| people << p }
    puts "Fetching SA Upper House ..."
    SA::MergeUpper.new.people.each { |p| people << p }

    ### Tasmania
    puts "Fetching TAS Lower House ..."
    TAS::CSVLower.new.people.each { |p| people << p }
    puts "Fetching TAS Upper House ..."
    TAS::CSVUpper.new.people.each { |p| people << p }

    ### VICTORIA
    puts "Fetching VIC Lower House ..."
    VIC::MergeLower.new.people.each { |p| people << p }
    puts "Fetching VIC Upper House ..."
    VIC::MergeUpper.new.people.each { |p| people << p }

    ### Western Australia
    puts "Fetching WA Lower House ..."
    WA::MergeLower.new.people.each { |p| people << p }
    puts "Fetching WA Upper House ..."
    WA::MergeUpper.new.people.each { |p| people << p }

    create_csv(people)
    people
  end

  def self.create_csv(people)
    filename = "tmp/csv_all_representatives.csv"
    File.delete(filename) if File.exist?(filename)

    CSV.open(filename, "wb") do |csv|
      csv << ["title", "first_name", "last_name", "preferred_name", "honorifics", "salutation", "gender", "email", "phone", "physical_address", "postal_address", "party_name", "electorate_name", "electorate_house", "electorate_state", "lower_house", "state_government"]
      people.each do |p|
        csv << [p.title, p.first_name, p.last_name, p.preferred_name, p.honorifics, p.salutation, p.gender, p.email, "'#{p.phone}'", p.physical_address, p.postal_address, p.party_name, p.electorate.name, p.electorate.house, p.electorate.state, p.electorate.lower_house, p.electorate.state_government]
      end
    end
  end

end
