module MyRepresentatives
  module ACT
    class CSVLower
      include MyRepresentatives::Fileable
      include MyRepresentatives::Guessable

      attr_accessor :csv_url, :csv_filename, :people, :logger

      def initialize
        @logger = Logger.new(STDOUT)
        @csv_url = "https://www.parliament.act.gov.au/__data/assets/file/0011/874235/Members-mail-merge-list-2016-1108.csv"
        @csv_filename = "tmp/csv_act_lower.csv"
        @people = []

        csv_from_url
        people_from_csv
      end


      private

        def csv_from_url
          create_tmp

          begin
            open(@csv_filename, "wb") do |file|
              open(@csv_url) do |uri|
                file.write(uri.read)
              end
            end
          rescue SocketError => err
            @logger.debug("Unable to connect to #{@csv_url}")
            raise err
          end
        end

        def people_from_csv
          CSV.foreach(@csv_filename, headers: true) do |row|

            # Setup the electorate
            electorate_name = find_electorate(row)
            electorate      = Electorate.new(electorate_name)
            electorate.state_act_lower!

            # Setup the Representative (Person)
            person = Person.new(electorate)

            person.title                      = find_title(row)
            person.first_name                 = find_first_name(row)
            person.last_name                  = find_last_name(row)
            person.email                      = find_email(row)
            person.phone                      = find_phone(row)
            person.party_name                 = find_party(row)
            person.honorifics                 = "MLA"
            person.formal_name                = format_formal_name(person)
            person.physical_address           = format_physical_address(row)
            person.postal_address             = format_postal_address(row)
            person.gender                     = guess_gender(person.title)
            person.preferred_name             = nil
            person.salutation                 = nil
            person.image_url                  = nil
            person.homepage_url               = nil

            @people << person
          end
        end

        def find_first_name(arr)
          arr["F_Name"]
        end

        def find_last_name(arr)
          if arr && arr["L_Name"]
            arr["L_Name"].gsub(" MLA","")
          else
            nil
          end
        end

        def find_electorate(arr)
          if arr && arr["JobTitle"]
            arr["JobTitle"].gsub("Member for ","")
          else
            nil
          end
        end

        def find_email(arr)
          arr["Email"]
        end

        def find_party(arr)
          arr["Party"]
        end

        def find_phone(arr)
          arr["Phone"]
        end

        def find_title(arr)
          arr["Title"]
        end

        def format_formal_name(person)
          "#{person.title} #{person.first_name} #{person.last_name} #{person.honorifics}"
        end

        def format_physical_address(arr)
          "#{arr["Address1"]}\n#{arr["City"]} #{arr["State"]} #{arr["PostCode"]}"
        end

        def format_postal_address(arr)
          "#{arr["Address1"]}\n#{arr["City"]} #{arr["State"]} #{arr["PostCode"]}"
        end

    end # CSVLower
  end # ACT
end # MyRepresentatives
