module MyRepresentatives
  module ACT
    class WebIndexRow
      attr_accessor :document

      def initialize(document)
        raise MyRepresentatives::NokogiriDocumentExpectedError unless document && document.is_a?(Nokogiri::XML::Element)
        @document = document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def first_name
        begin
          @document.css("a")[0].text.split(",")[1]
        rescue
          nil
        end
      end

      def last_name
        begin
          @document.css("a")[0].text.split(",")[0]
        rescue
        end
      end

      def electorate_name
        begin
          @document.css("td")[2].text
        rescue
        end
      end

      def party_name
        begin
          @document.css("td")[3].text
        rescue
        end
      end

      def phone
        begin
          text = @document.css("td")[4].text
          regex = /Ph:(.+?)$/
          regex.match(text)[1].strip
        rescue
          nil
        end
      end

      def email
        begin
          text = @document.css("td")[4].text
          regex = /^(.+?@.+?.gov.au)/
          regex.match(text)[1].strip
        rescue
          nil
        end
      end

      def address
        nil
      end

      def homepage_url
        begin
          @document.css("a")[0].attr("href")
        rescue
          nil
        end
      end

      private

        def test_document_for_validity
          if @document && @document.css("a") && @document.css("td")
            true
          else
            @logger.debug("Failed to find a valid document to scrape")
            false
          end
        end

    end # WebIndexRow
  end # ACT
end # MyRepresentatives
