module MyRepresentatives
  module ACT
    class WebLower

      attr_accessor :documents, :people

      def initialize
        @logger = Logger.new(STDOUT)
        @documents = WebIndex.new.representative_documents
        @people = []

        @documents.each do |document|
          row = WebIndexRow.new(document)
          create_person_from_row(row)
        end

        @people.each do |person|
          update_person(person)
        end
      end

      private

        def create_person_from_row(row)
          @logger.info("Attempting to create #{row.first_name} #{row.last_name}")

          # Setup the electorate
          electorate_name = row.electorate_name
          electorate      = MyRepresentatives::Electorate.new(electorate_name)
          electorate.state_act_lower!

          # Setup the Representative (Person)
          person = MyRepresentatives::Person.new(electorate)
          person.first_name                 = row.first_name
          person.last_name                  = row.last_name
          person.email                      = row.email
          person.phone                      = row.phone
          person.party_name                 = row.party_name
          person.physical_address           = row.address
          person.postal_address             = row.address
          person.homepage_url               = row.homepage_url
          person.honorifics                 = "MLA"
          person.formal_name                = format_formal_name(person)
          person.title                      = nil
          person.gender                     = nil
          person.preferred_name             = nil
          person.salutation                 = nil
          person.image_url                  = nil

          @people << person

        end

        def update_person(person)
          details_page = WebShow.new(person.homepage_url)
          person.image_url = details_page.image_url
        end

        def format_formal_name(person)
          "#{person.first_name} #{person.last_name} #{person.honorifics}"
        end

    end # WebLower
  end # ACT
end # MyRepresentatives
