module MyRepresentatives
  module ACT
    class WebShow

      attr_accessor :url, :document, :logger

      def initialize(url)
        @logger = Logger.new(STDOUT)
        raise MyRepresentatives::InvalidURLError unless url && url.is_a?(String)
        @url = url
        fetch_document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def image_url
        begin
          @document.css("div.section").css("img")[0].attr('src')
        rescue NoMethodError
          nil
        end
      end

      private

        def fetch_document
          begin
            request   = open(@url)
            @document = Nokogiri::HTML(request)
          rescue => err
            @logger.debug("Failed to connect to the url: #{@url}")
            raise err
          end
        end

        def test_document_for_validity
          if @document && @document.css("div.section") && @document.css("div.section").css("img")
            true
          else
            @logger.debug("Failed to find a valid document to scrape")
            false
          end
        end

    end # WebShow
  end # ACT
end # MyRepresentatives
