module MyRepresentatives
  module Commonwealth
    class CSVEmail
      include MyRepresentatives::Abbreviatable
      include MyRepresentatives::Fileable
      include MyRepresentatives::Guessable

      attr_accessor :csv_url, :csv_filename, :people, :logger

      def initialize
        @logger       = Logger.new(STDOUT)
        # Email addresses for Commonwealth Members and Senators tend to be a little harder to find
        # At this time, this gem uses a csv manually created by https://github.com/tennantje/.
        # https://gist.github.com/tennantje/8ee584d9c534ce6a57910668b277394d
        @csv_url      = "https://gist.githubusercontent.com/tennantje/8ee584d9c534ce6a57910668b277394d/raw"
        @csv_filename = "tmp/csv_commonwealth_emails.csv"
        @people       = []

        csv_from_url
        people_from_csv
      end

      private

        def csv_from_url
          create_tmp
          begin
            open(@csv_filename, "wb") do |file|
              open(@csv_url) do |uri|
                 file.write(uri.read)
              end
            end
          rescue SocketError => err
            @logger.debug("Unable to connect to #{@csv_url}")
            raise err
          end
        end

        def people_from_csv
          CSV.foreach(@csv_filename, headers: true) do |row|

            # Setup the electorate
            electorate_name  = "Not necessary"                # These values don't matter, and are used to force-validate the object
            electorate_state = "ACT"                          # These values don't matter, and are used to force-validate the object
            electorate       = Electorate.new(electorate_name)# These values don't matter, and are used to force-validate the object
            electorate.commonwealth_lower!(electorate_state)  # These values don't matter, and are used to force-validate the object

            # Setup the Representative (Person)
            person = Person.new(electorate)

            person.first_name                 = find_first_name(row)
            person.last_name                  = find_last_name(row)
            person.formal_name                = find_formal_name(row)
            person.phone                      = find_phone(row)
            person.email                      = find_email(row)
            person.title                      = nil
            person.honorifics                 = nil
            person.party_name                 = nil
            person.salutation                 = nil
            person.gender                     = nil
            person.preferred_name             = nil
            person.physical_address           = nil
            person.postal_address             = nil
            person.image_url                  = nil
            person.homepage_url               = nil

            @people << person
          end
        end

        def find_first_name(arr)
          arr["first"]
        end

        def find_last_name(arr)
          arr["last"]
        end

        def find_formal_name(arr)
          arr["formal_name"]
        end

        def find_email(arr)
          arr["email"]
        end

        def find_phone(arr)
          arr["phone"]
        end

    end #CSVLower
  end # Commonwealth
end # MyRepresentatives
