module MyRepresentatives
  module Commonwealth
    class WebIndex
      attr_accessor :index_url, :document, :senator_urls, :member_urls

      def initialize
        @logger       = Logger.new(STDOUT)
        @index_url    = nil
        @document     = nil
        @member_urls  = []
        @senator_urls = []

        (1..13).each do |page|
          @index_url = "http://www.aph.gov.au/Senators_and_Members/Parliamentarian_Search_Results?page=#{page}&expand=1&q=&mem=1&par=-1&gen=0&ps=12&st=1"
          @document  = find_representatives
          representative_urls_from_document( { lower_house: true } )
        end

        (1..7).each do |page|
          @index_url = "http://www.aph.gov.au/Senators_and_Members/Parliamentarian_Search_Results?page=#{page}&expand=1&q=&sen=1&par=-1&gen=0&ps=12&st=1"
          @document  = find_representatives
          representative_urls_from_document( { lower_house: false } )
        end
      end


      private

        def find_representatives
          begin
            request = open(@index_url)
            Nokogiri::HTML(request)
          rescue SocketError => err
            @logger.debug("Unable to connect to #{@index_url}")
            raise err
          end
        end

        def representative_urls_from_document(options = { lower_house: true } )
          begin
            results = @document.css("div.search-filter-results")
            representatives = results.css("div.row") if results
          rescue
          end

          representatives.each do |row|
            begin
              @member_urls  << "http://www.aph.gov.au" + row.css("h4.title").css("a").first.attr("href") if options[:lower_house]
              @senator_urls << "http://www.aph.gov.au" + row.css("h4.title").css("a").first.attr("href") if !options[:lower_house]
            rescue
            end
          end
        end

    end # WebIndex
  end # Commonwealth
end # MyRepresentatives
