module MyRepresentatives
  module Commonwealth
    class WebShow

      attr_accessor :url, :document, :logger

      def initialize(url)
        @logger = Logger.new(STDOUT)
        raise MyRepresentatives::InvalidURLError unless url && url.is_a?(String)
        @url = url
        fetch_document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def homepage_url
        @url
      end

      def formal_name
        begin
          @document.css("h1").text.strip
        rescue NoMethodError
          nil
        end
      end

      def party_name
        begin
          @document.css(".medium-7").at('dt:contains("Party")').next_element.text.strip
        rescue NoMethodError
          nil
        end
      end

      def phone
        begin
          @document.css("#panel11").at('dt:contains("Telephone")').next_element.text.strip
        rescue NoMethodError
          nil
        end
      end

      def email
        begin
          @document.css("#panel31").at('dt:contains("Email")').next_element.text.strip
        rescue NoMethodError
          nil
        end
      end

      def electorate_name
        begin
          @document.css(".medium-7").css("h3").text.split(",")[0].strip.gsub("Member for ","").gsub("Senator for ","").gsub(/\s{2,}/,"")
        rescue NoMethodError
          nil
        end
      end

      def state_name
        begin
          @document.css(".medium-7").css("h3").text.split(",")[1].strip.gsub("Member for ","").gsub("Senator for ","").gsub(/\s{2,}/,"")
        rescue NoMethodError
          nil
        end
      end

      def image_url
        begin
          @document.css(".medium-3").css("img").attr('src').value.strip
        rescue NoMethodError
          nil
        end
      end

      private

        def fetch_document
          begin
            request   = open(@url)
            @document = Nokogiri::HTML(request)
          rescue => err
            @logger.debug("Failed to connect to the url: #{@url}")
            raise err
          end
        end

        def test_document_for_validity
          true
          # if @document && @document.css("div.section") && @document.css("div.section").css("img")
          #   true
          # else
          #   @logger.debug("Failed to find a valid document to scrape")
          #   false
          # end
        end

    end # WebShow
  end # Commonwealth
end # MyRepresentatives
