module MyRepresentatives
  module NSW
    class WebIndex
      attr_accessor :index_url, :document, :upper_urls, :lower_urls

      def initialize
        @logger     = Logger.new(STDOUT)
        @index_url  = nil
        @document   = nil
        @lower_urls = []
        @upper_urls = []

        # Lower House
        @index_url = "https://www.parliament.nsw.gov.au/members/pages/all-members.aspx?house=LA"
        @document  = find_representatives
        representative_urls_from_document( { lower_house: true } )

        # Upper House
        @index_url = "https://www.parliament.nsw.gov.au/members/pages/all-members.aspx?house=LC"
        @document  = find_representatives
        representative_urls_from_document( { lower_house: false } )

      end


      private

        def find_representatives
          begin
            request = open(@index_url)
            Nokogiri::HTML(request)
          rescue SocketError => err
            @logger.debug("Unable to connect to #{@index_url}")
            raise err
          end
        end

        def representative_urls_from_document(options = { lower_house: true } )
          begin
            representatives = @document.css("table").css("a.prl-name-link.green") if options[:lower_house]
            representatives = @document.css("table").css("a.prl-name-link.maroon") if !options[:lower_house]
          rescue
          end

          representatives.each do |row|
            begin
              @lower_urls  << "https://www.parliament.nsw.gov.au" + row.attr("href") if options[:lower_house]
              @upper_urls << "https://www.parliament.nsw.gov.au" + row.attr("href") if !options[:lower_house]
            rescue
            end
          end
        end

    end # WebIndex
  end # NSW
end # MyRepresentatives
