module MyRepresentatives
  module NSW
    class WebShow
      include MyRepresentatives::Guessable

      attr_accessor :url, :document, :logger

      def initialize(url)
        @logger = Logger.new(STDOUT)
        raise MyRepresentatives::InvalidURLError unless url && url.is_a?(String)
        @url = url
        fetch_document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def homepage_url
        @url
      end

      def formal_name
        begin
          unformatted_name.split(",")[0].titleize
        rescue NoMethodError
          nil
        end
      end

      def first_name
        begin
          guess_first(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def preferred_name
        begin
          guess_preferred(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def last_name
        begin
          guess_last(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def party_name
        begin
        rescue NoMethodError
          nil
        end
      end

      def phone
        begin
          phone = @document.css(".contact_office").css("th.label_cell")
          index = phone.find_index { |p| p.text == "P" }

          if index
            phone[index].next_element.text
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def email
        begin
          email = @document.css(".contact_office").at('a:contains("@parliament.nsw.gov.au")')
          if email.is_a?(Array)
            email.first.attr('href').strip.gsub("mailto:","")
          else
            email.attr('href').strip.gsub("mailto:","")
          end
        rescue NoMethodError
          nil
        end
      end

      def electorate_name
        begin
          electorate = @document.css(".office").css("div.title")[0].text.strip
          if electorate.include?("Electorate Office")
            electorate.gsub!(" Electorate Office","")
          else
            "All NSW"
          end
        rescue NoMethodError
          nil
        end
      end

      def image_url
        begin
          "https://www.parliament.nsw.gov.au" + @document.css("div.img_position").css("img").attr('src').value.strip
        rescue NoMethodError
          nil
        end
      end

      private

        def fetch_document
          begin
            request   = open(@url)
            @document = Nokogiri::HTML(request)
          rescue => err
            @logger.debug("Failed to connect to the url: #{@url}")
            raise err
          end
        end

        def test_document_for_validity
          true
          # if @document && @document.css("div.section") && @document.css("div.section").css("img")
          #   true
          # else
          #   @logger.debug("Failed to find a valid document to scrape")
          #   false
          # end
        end

        def unformatted_name
          begin
            @document.css("h1.page-title").text.strip
          rescue NoMethodError
            nil
          end
        end

    end # WebShow
  end # NSW
end # MyRepresentatives
