module MyRepresentatives
  module NT
    class WebShow
      include MyRepresentatives::Guessable

      attr_accessor :url, :document, :logger

      def initialize(url)
        @logger = Logger.new(STDOUT)
        raise MyRepresentatives::InvalidURLError unless url && url.is_a?(String)
        @url = url
        fetch_document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def homepage_url
        @url
      end

      def formal_name
        begin
          @document.css("h1#main").text
        rescue NoMethodError
          nil
        end
      end

      def title
        begin
          guess_title(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def first_name
        begin
          guess_first(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def preferred_name
        begin
          guess_preferred(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def last_name
        begin
          guess_last(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def phone
        begin
          @document.css("table").at('th:contains("Phone (business hours)")').next_element.text.strip.gsub("+61 ","")
        rescue NoMethodError
          nil
        end
      end

      def email
        begin
          @document.css("table").at('th:contains("Electorate office")').next_element.text.strip
        rescue NoMethodError
          nil
        end
      end

      def electorate_name
        begin
          @document.css("table").at('th:contains("Electorate")').next_element.text.strip
        rescue NoMethodError
          nil
        end
      end

      def party_name
        begin
          @document.css("table").at('th:contains("Party")').next_element.text.strip
        rescue NoMethodError
          nil
        end
      end

      def physical_address
        begin
          @document.css("table").at('th:contains("Address")').next_element.text.strip.gsub(", ","\n")
        rescue NoMethodError
          nil
        end
      end

      def postal_address
        begin
          @document.css("table").at('th:contains("Postal address")').next_element.text.strip.gsub(", ","\n")
        rescue NoMethodError
          nil
        end
      end

      def image_url
        begin
          @document.css("div.thumbnail").css("img").attr('src').value
        rescue NoMethodError
          nil
        end
      end

      private

        def fetch_document
          begin
            request   = open(@url)
            @document = Nokogiri::HTML(request)
          rescue => err
            @logger.debug("Failed to connect to the url: #{@url}")
            raise err
          end
        end

        def test_document_for_validity
          true
        end

    end # WebShow
  end # NT
end # MyRepresentatives
