require 'active_support'
require 'active_support/inflector'

module MyRepresentatives
  class Person
    class Error < StandardError; end
    class IsNotAnElectorateObjectError < Error; end

    include MyRepresentatives::Hashable

    attr_accessor :electorate, :successful_merge
    attr_reader :formal_name, :first_name, :last_name, :preferred_name, :salutation, :title, :honorifics, :gender, :email, :phone, :physical_address, :postal_address, :image_url, :homepage_url, :party_name

    def initialize(electorate)
      raise IsNotAnElectorateObjectError unless electorate && electorate.is_a?(Electorate)
      @electorate       = electorate
      @successful_merge = false
    end

    def to_hash
      super
    end

    def formal_name=(value)
      @formal_name = if value
        if value.strip.empty?
          nil
        else
          value.strip.gsub(/\s{2,}/," ")
        end
      else
        nil
      end
    end

    def first_name=(value)
      @first_name = if value
        value.strip
      else
        nil
      end
    end

    def last_name=(value)
      @last_name = if value
        value.strip.gsub(" MP", "").gsub(" MLA", "").gsub(" MLC", "").gsub(" QC", "").gsub(" CSC", "").gsub(" AO", "").gsub(" AOM", "")
      else
        nil
      end
    end

    def preferred_name=(value)
      @preferred_name = if value
        value.strip
      else
        nil
      end
    end

    def salutation=(value)
      @salutation = if value
        value.strip
      else
        nil
      end
    end

    def title=(value)
      @title = if value
        if value.strip.empty?
          nil
        else
          value.strip
        end
      else
        nil
      end
    end

    def honorifics=(value)
      @honorifics = if value
        value.strip
      else
        nil
      end
    end

    def gender=(value)
      @gender = if value
        value.strip.titleize
      else
        nil
      end
    end

    def email=(value)
      @email = if value
        value.downcase.strip.split(" ")[0]
      else
        nil
      end
    end

    def phone=(value)
      @phone = if value
        value.strip.gsub(/\D/, '')
      else
        nil
      end
    end

    def physical_address=(value)
      @physical_address = if value && !value.upcase.include?("PO BOX")
        if value.strip.empty?
          nil
        else
          value.strip.gsub(/[ ]{2,}/," ").gsub("\n\n","\n").gsub("\n ","\n")
        end
      else
        nil
      end
    end

    def postal_address=(value)
      @postal_address = if value
        if value.strip.empty?
          nil
        else
          value.strip.gsub(/[ ]{2,}/," ").gsub("\n\n","\n").gsub("\n ","\n")
        end
      else
        nil
      end
    end

    def image_url=(value)
      @image_url = if value
        value.strip
      else
        nil
      end
    end

    def homepage_url=(value)
      @homepage_url = if value
        value.strip
      else
        nil
      end
    end

    def party_name=(value)
      @party_name = if value
        if value.upcase == "LP" || value.upcase == "LIB"
          "Liberal Party"
        elsif value.upcase == "ALP" || value == "Australian Labor Party"
          "Australian Labor Party"
        elsif value.upcase == "AG"
          "Australian Greens"
        elsif value.upcase == "NATS" || value.upcase == "NAT"
          "The Nationals"
        elsif value.upcase == "AUS" || value.upcase == "KAP"
          "Katter's Australian Party"
        elsif value.upcase.start_with?("IND")
          "Independent"
        elsif value.upcase == "NXT"
          "Nick Xenophon Team"
        elsif value.upcase == "JLN"
          "Jacqui Lambie Network"
        elsif value.upcase == "AC"
          "Australan Conservatives"
        elsif value.upcase == "PHON" || value.upcase == "ONP"
          "Pauline Hanson's One Nation"
        elsif value.upcase == "DJHP"
          "Derryn Hinch's Justice Party"
        elsif value.upcase == "LDP"
          "Liberal Democrats"
        elsif value.upcase == "CLP"
          "Country Liberal Party"
        elsif value.upcase == "LNP"
          "Liberal National Party"
        elsif value.upcase == "GWA"
          "Greens Western Australia"
        elsif value.upcase == "SFF"
          "Shooters, Fisher & Farmers Party"
        elsif value.upcase == "NPA"
          "Greens Western Australia"
        else
          value.strip
        end
      else
        nil
      end
    end

  end
end
