require 'excel2csv'

module MyRepresentatives
  module QLD
    class CSVLower
      include MyRepresentatives::Fileable
      include MyRepresentatives::Guessable

      attr_accessor :xls_url, :csv_filename, :xls_filename, :people

      def initialize
        self.xls_url = "https://www.parliament.qld.gov.au/documents/Members/mailingLists/MEMMERGEEXCEL.xls"
        self.xls_filename = "tmp/csv_qld_lower.xls"
        self.csv_filename = "tmp/csv_qld_lower.csv"
        self.people = []

        csv_from_url
        people_from_csv
      end

      def csv_from_url
        create_tmp
        open(@xls_filename, "wb") do |file|
          open(@xls_url) do |uri|
             file.write(uri.read)
          end
        end

        excel = Excel2CSV.read(@xls_filename)
        CSV.open(@csv_filename, "wb") do |csv|
          excel.each do |row|
            csv << row
          end
        end
        FileUtils.rm_r(@xls_filename)
      end

      def people_from_csv
        CSV.foreach(@csv_filename, headers: true) do |row|

          # Setup the electorate
          electorate_name = find_electorate(row)
          electorate      = Electorate.new(electorate_name)
          electorate.state_qld_lower!

          # Setup the Representative (Person)
          person = Person.new(electorate)

          person.title                      = find_title(row)
          person.first_name                 = find_first_name(row)
          person.last_name                  = find_last_name(row)
          person.email                      = find_email(row)
          person.phone                      = find_phone(row)
          person.party_name                 = find_party(row)
          person.formal_name                = format_formal_name(person)
          person.physical_address           = format_physical_address(row)
          person.postal_address             = format_postal_address(row)
          person.gender                     = guess_gender(person.title)
          person.honorifics                 = "MP"
          person.preferred_name             = nil
          person.salutation                 = nil
          person.image_url                  = nil
          person.homepage_url               = nil

          @people << person
        end
      end

      private

        def find_first_name(arr)
          arr["first"]
        end

        def find_last_name(arr)
          arr["last"]
        end

        def find_electorate(arr)
          if arr && arr["electorate"]
            arr["electorate"].gsub("Member for ","")
          else
            nil
          end
        end

        def find_party(arr)
          arr["party"]
        end

        def find_email(arr)
          nil
        end

        def find_phone(arr)
          nil
        end

        def find_title(arr)
          arr["title"]
        end

        def format_formal_name(person)
          "#{person.title} #{person.first_name} #{person.last_name}"
        end

        def format_physical_address(arr)
          "#{arr["address 1"]}\n#{arr["address 2"]}"
        end

        def format_postal_address(arr)
          "#{arr["address 1"]}\n#{arr["address 2"]}"
        end

    end # CSVLower
  end # QLD
end # MyRepresentatives
