module MyRepresentatives
  module QLD
    class WebShow
      include MyRepresentatives::Guessable

      attr_accessor :url, :document, :logger

      def initialize(url)
        @logger = Logger.new(STDOUT)
        raise MyRepresentatives::InvalidURLError unless url && url.is_a?(String)
        @url = url
        fetch_document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def homepage_url
        @url
      end

      def formal_name
        begin
          @document.css(".member-heading").css("h1").text
        rescue NoMethodError
          nil
        end
      end

      def title
        begin
          guess_title(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def first_name
        begin
          guess_first(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def preferred_name
        begin
          guess_preferred(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def last_name
        begin
          guess_last(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def phone
        begin
          regex = /Phone: (.+?)[Fax|Email]/
          text = @document.at('strong:contains("Phone:")').parent.text.strip
          match = text.match(regex)
          if match
            match[1]
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def email
        begin
          regex = /Email: (.+?@parliament.qld.gov.au)/
          text = @document.at('strong:contains("Email:")').parent.text.strip
          match = text.match(regex)
          if match
            match[1]
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def electorate_name
        begin
          regex = /^\s+([A-Z].+?) -/
          text = @document.at('strong:contains("Electorate")').parent.text.strip
          match = text.match(regex)
          if match
            match[1]
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def party_name
        begin
          regex = /^\s+([A-Z].+?)$/
          text = @document.at('strong:contains("Party")').parent.text.strip
          match = text.match(regex)
          if match
            match[1].gsub(/ (\(.+?\))/,"")
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def image_url
        begin
          "https://www.parliament.qld.gov.au"+@document.css("div.member-bio").css("img").attr('src').value.gsub("../../..","")
        rescue NoMethodError
          nil
        end
      end

      private

        def fetch_document
          begin
            request   = open(@url)
            @document = Nokogiri::HTML(request)
          rescue => err
            @logger.debug("Failed to connect to the url: #{@url}")
            raise err
          end
        end

        def test_document_for_validity
          true
        end

    end # WebShow
  end # QLD
end # MyRepresentatives
