module MyRepresentatives
  module SA
    class CSVLower
      include MyRepresentatives::Fileable
      include MyRepresentatives::Guessable

      attr_accessor :csv_url, :csv_filename, :people

      def initialize
        @csv_url      = "http://www2.parliament.sa.gov.au/Internet/DesktopModules/CreateMM.aspx?type=ha"
        @csv_filename = "tmp/csv_sa_lower.csv"
        @people       = []

        csv_from_url
        people_from_csv
      end

      def csv_from_url
        create_tmp

        f = open(@csv_url)
        doc = Nokogiri::HTML(f)

        CSV.open(@csv_filename, "wb") do |csv|
          csv << ["title", "first", "last", "electorate", "address", "email"]
          loops = 0

          doc.css("table").css("tr").each do |row|
            if loops > 0
              arr = []
              row.css("td").each do |cell|
                arr << cell.text
              end
              csv << arr
            end
            loops += 1
          end
        end
      end

      def people_from_csv
        CSV.foreach(@csv_filename, headers: true) do |row|

          # Setup the electorate
          electorate_name = find_electorate(row)
          electorate      = Electorate.new(electorate_name)
          electorate.state_sa_lower!

          # Setup the Representative (Person)
          person = Person.new(electorate)

          person.title                      = find_title(row)
          person.first_name                 = find_first_name(row)
          person.last_name                  = find_last_name(row)
          person.email                      = find_email(row)
          person.phone                      = find_phone(row)
          person.party_name                 = find_party(row)
          person.gender                     = guess_gender(person.title)
          person.formal_name                = format_formal_name(person)
          person.physical_address           = format_physical_address(row)
          person.postal_address             = format_postal_address(row)
          person.honorifics                 = "MP"
          person.preferred_name             = nil
          person.salutation                 = nil
          person.image_url                  = nil
          person.homepage_url               = nil

          @people << person
        end
      end

      private

        def find_first_name(arr)
          arr["first"]
        end

        def find_last_name(arr)
          arr["last"]
        end

        def find_title(arr)
          arr["title"]
        end

        def find_electorate(arr)
          if arr && arr["electorate"]
            arr["electorate"].gsub("Member for ","")
          else
            nil
          end
        end

        def find_email(arr)
          arr["email"]
        end

        def find_party(arr)
          nil
        end

        def find_phone(arr)
          nil
        end

        def format_formal_name(person)
          "#{person.title} #{person.first_name} #{person.last_name}"
        end

        def format_physical_address(arr)
          "#{arr["address"]}"
        end

        def format_postal_address(arr)
          "#{arr["address"]}"
        end

    end # CSVLower
  end # SA
end # MyRepresentatives
