module MyRepresentatives
  module SA
    class WebShow
      include MyRepresentatives::Guessable

      attr_accessor :url, :document, :logger

      def initialize(url)
        @logger = Logger.new(STDOUT)
        raise MyRepresentatives::InvalidURLError unless url && url.is_a?(String)
        @url = url
        fetch_document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def homepage_url
        @url
      end

      def formal_name
        begin
          @document.title.strip.gsub("Profile: ","")
        rescue NoMethodError
          nil
        end
      end

      def title
        begin
          guess_title(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def first_name
        begin
          guess_first(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def last_name
        begin
          guess_last(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def preferred_name
        begin
          guess_preferred(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def electorate_name
        begin
          @document.at('td.boxedtext:contains("Electorate")').next_element.text
        rescue NoMethodError
          nil
        end
      end

      def party_name
        begin
          @document.at('td.boxedtext:contains("Political Party")').next_element.text
        rescue NoMethodError
          nil
        end
      end

      def email
        begin
          regex = /Email(.+?@.+?.sa.gov.au)/
          text = @document.text.strip
          match = text.match(regex)
          if match
            match[1]
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def image_url
        id = homepage_url.split("=")
        "http://www2.parliament.sa.gov.au/FormerMembers/Common/Handler/PersonImage.ashx?PersonId=#{id.last}"
      end

      def phone
        begin
          phone = @document.at('b:contains("Electorate Telephone:")')
          alt_phone = @document.at('b:contains("Telephone:")')
          if phone
            phone = phone.parent.text
            regex = /Electorate Telephone:(08 [0-9]{4} [0-9]{4})/
            alt_regex = /Electorate Telephone:([0-9]{4} [0-9]{4})/
            match = phone.match(regex)
            match_alt = phone.match(alt_regex)

            if match
              match[1]
            elsif match_alt
              "08"+match_alt[1]
            else
              nil
            end
          elsif alt_phone
            phone = alt_phone.parent.text
            regex = /Telephone:(08 [0-9]{4} [0-9]{4})/
            alt_regex = /Telephone:([0-9]{4} [0-9]{4})/
            last_attempt = /Telephone:(1800 [0-9]{3} [0-9]{3})/
            match = phone.match(regex)
            match_alt = phone.match(alt_regex)
            match_last = phone.match(last_attempt)

            if match
              match[1]
            elsif match_alt
              "08"+match_alt[1]
            elsif match_last
              match_last[1]
            else
              nil
            end
          else
            nil
          end
        rescue
          nil
        end
      end

      private

        def fetch_document
          begin
            request   = open(@url)
            @document = Nokogiri::HTML(request)
          rescue => err
            @logger.debug("Failed to connect to the url: #{@url}")
            raise err
          end
        end

        def test_document_for_validity
          true
        end

    end # WebShow
  end # SA
end # MyRepresentatives
