module MyRepresentatives
  module VIC
    class CSVLower
      include MyRepresentatives::Fileable
      include MyRepresentatives::Guessable

      attr_accessor :csv_url, :csv_filename, :people

      def initialize
        @csv_url      = "http://www.parliament.vic.gov.au/members/house/mla?format=csv"
        @csv_filename = "tmp/csv_vic_lower.csv"
        @people       = []

        csv_from_url
        people_from_csv
      end

      private

        def csv_from_url
          create_tmp
          begin
            open(@csv_filename, "wb") do |file|
              open(@csv_url) do |uri|
                 file.write(uri.read)
              end
            end
          rescue SocketError => err
            @logger.debug("Unable to connect to #{@csv_url}")
            raise err
          end
        end

        def people_from_csv
          CSV.foreach(@csv_filename, headers: true) do |row|

            # Setup the electorate
            electorate_name = find_electorate(row)
            electorate      = Electorate.new(electorate_name)
            electorate.state_vic_lower!

            # Setup the Representative (Person)
            person = Person.new(electorate)

            person.formal_name                = find_formal_name(row)
            person.gender                     = find_gender(row)
            person.email                      = find_email(row)
            person.phone                      = find_phone(row)
            person.party_name                 = find_party(row)
            person.first_name                 = guess_first(person.formal_name)
            person.last_name                  = guess_last(person.formal_name)
            person.title                      = guess_title(person.formal_name)
            person.physical_address           = format_physical_address(row)
            person.postal_address             = format_postal_address(row)
            person.honorifics                 = "MP"
            person.preferred_name             = nil
            person.salutation                 = nil
            person.image_url                  = nil
            person.homepage_url               = nil

            @people << person
          end
        end

        def find_formal_name(arr)
          arr["Name"]
        end

        def find_electorate(arr)
          arr["Electorate"]
        end

        def find_email(arr)
          arr["Email"]
        end

        def find_gender(arr)
          arr["Sex"]
        end

        def find_party(arr)
          arr["Party"]
        end

        def find_phone(arr)
          arr["Phone"]
        end

        def format_physical_address(arr)
          "#{arr["Electorate Office Address line 1"]}\n#{arr["Electorate Office Address line 2"]}\n#{arr["Electorate Office Address line 3"]}\n#{arr["Electorate Office Address line 4"]} #{arr["Electorate Office Address line 5"]} #{arr["Electoral Office Postcode"]}"
        end

        def format_postal_address(arr)
          "#{arr["PO Address line 1"]}\n#{arr["PO Address line 2"]}\n#{arr["PO Address line 3"]}\n#{arr["PO Address line 4"]} #{arr["PO Address line 5"]}"
        end

    end # CSVLower
  end # VIC
end # MyRepresentatives
