module MyRepresentatives
  module VIC
    class WebLower
      include MyRepresentatives::Abbreviatable
      include MyRepresentatives::Guessable

      attr_accessor :urls, :people

      def initialize
        @logger = Logger.new(STDOUT)
        @urls = WebIndex.new.lower_urls
        @people = []

        @urls.each do |url|
          document = WebShow.new(url)
          create_person_from_document(document)
        end
      end

      private

        def create_person_from_document(document)
          @logger.info("Attempting to create #{document.formal_name}")

          # Setup the electorate
          electorate_name = document.electorate_name
          electorate      = MyRepresentatives::Electorate.new(electorate_name)
          electorate.state_vic_lower!

          # Setup the Representative (Person)
          person = MyRepresentatives::Person.new(electorate)
          person.formal_name                = document.formal_name
          person.first_name                 = guess_first(document.formal_name)
          person.last_name                  = guess_last(document.formal_name)
          person.title                      = guess_title(document.formal_name)
          person.email                      = document.email
          person.phone                      = document.phone
          person.party_name                 = document.party_name
          person.image_url                  = document.image_url
          person.homepage_url               = document.homepage_url
          person.preferred_name             = document.preferred_name
          person.gender                     = guess_gender(document.formal_name)
          person.physical_address           = nil
          person.postal_address             = nil
          person.honorifics                 = nil
          person.salutation                 = nil

          @people << person

        end

    end # WebLower
  end # VIC
end # MyRepresentatives
