module MyRepresentatives
  module VIC
    class WebShow
      include MyRepresentatives::Guessable

      attr_accessor :url, :document, :logger

      def initialize(url)
        @logger = Logger.new(STDOUT)
        raise MyRepresentatives::InvalidURLError unless url && url.is_a?(String)
        @url = url
        fetch_document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def homepage_url
        @url
      end

      def formal_name
        begin
          @document.css("div#page-title").css("h2").text
        rescue NoMethodError
          nil
        end
      end

      def title
        begin
          guess_title(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def first_name
        begin
          guess_first(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def last_name
        begin
          guess_last(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def preferred_name
        begin
          guess_preferred(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def electorate_name
        begin
          @document.css("dl.member-overview").at('dt:contains("Electorate")').next_element.text
        rescue NoMethodError
          nil
        end
      end

      def party_name
        begin
          @document.css("dl.member-overview").at('dt:contains("Party")').next_element.text
        rescue NoMethodError
          nil
        end
      end

      def email
        begin
          @document.css("dl.member-overview").at('dt:contains("Email")').next_element.text.strip
        rescue
          nil
        end
      end

      def image_url
        begin
          @document.css("img.details-portrait").attr("src").value
        rescue
          nil
        end
      end

      def phone
        begin
          @document.css("dl.member-overview").at('dt:contains("Phone")').next_element.text.strip
        rescue
          nil
        end
      end

      private

        def fetch_document
          begin
            request   = open(@url)
            @document = Nokogiri::HTML(request)
          rescue => err
            @logger.debug("Failed to connect to the url: #{@url}")
            raise err
          end
        end

        def test_document_for_validity
          true
        end

    end # WebShow
  end # VIC
end # MyRepresentatives
