module MyRepresentatives
  module WA
    class CSVLower
      include MyRepresentatives::Fileable
      include MyRepresentatives::Guessable

      attr_accessor :xls_url, :xls_filename, :csv_filename, :people

      def initialize
        @xls_url      = "http://www.parliament.wa.gov.au/WebCMS/WebCMS.nsf/resources/file-mla-merge-data/$file/MLA%20Merge%20Data%2008062017.xls"
        @xls_filename = "tmp/csv_wa_lower.xls"
        @csv_filename = "tmp/csv_wa_lower.csv"
        @people       = []

        csv_from_url
        people_from_csv
      end

      private

        def csv_from_url
          create_tmp

          open(@xls_filename, "wb") do |file|
            open(@xls_url) do |uri|
               file.write(uri.read)
            end
          end

          excel = Excel2CSV.read(@xls_filename)
          CSV.open(@csv_filename, "wb") do |csv|
            excel.each_with_index do |row, index|

              if index == 0  # This exists to fix duplicate values in the header row
                renamed_postal_address = false
                renamed_electorate_address = false
                renamed_parliament_address = false
                new_row = []

                row.each do |col|
                  if col.downcase == "postal address" && renamed_postal_address == false
                    col = "postal_address_1"
                    renamed_postal_address = true
                  elsif col.downcase == "electorate address" && renamed_electorate_address == false
                    col = "electorate_address_1"
                    renamed_electorate_address = true
                  elsif col.downcase == "parliament" && renamed_parliament_address == false
                    col = "parliament_1"
                    renamed_parliament_address = true
                  end
                  new_row << col
                end
                csv << new_row
              else
                csv << row
              end
            end
          end
          FileUtils.rm_r(@xls_filename)
        end

        def people_from_csv
          CSV.foreach(@csv_filename, headers: true) do |row|

            if row["First Name"] && row["Surname"] && row["Electorate"] # Fix for blank rows

              # Setup the electorate
              electorate_name = find_electorate(row)
              electorate      = Electorate.new(electorate_name)
              electorate.state_wa_lower!

              # Setup the Representative (Person)
              person = Person.new(electorate)

              person.title                      = find_title(row)
              person.first_name                 = find_first_name(row)
              person.last_name                  = find_last_name(row)
              person.email                      = find_email(row)
              person.phone                      = find_phone(row)
              person.party_name                 = find_party(row)
              person.gender                     = guess_gender(row["Title"])
              person.formal_name                = format_formal_name(row,person)
              person.physical_address           = format_physical_address(row)
              person.postal_address             = format_postal_address(row)
              person.honorifics                 = "MLA"
              person.preferred_name             = nil
              person.salutation                 = nil
              person.image_url                  = nil
              person.homepage_url               = nil

              @people << person

            end
          end
        end

        def find_first_name(arr)
          arr["First Name"]
        end

        def find_last_name(arr)
          arr["Surname"]
        end

        def find_title(arr)
          arr["Hon."].nil? ? arr["Title"] : "Hon"
        end

        def find_electorate(arr)

          if arr && arr["Electorate"]
            arr["Electorate"].gsub("Member for ","")
          else
            nil
          end
        end

        def find_email(arr)
          arr["Member Email"]
        end

        def find_party(arr)
          nil
        end

        def find_phone(arr)
          nil
        end

        def format_formal_name(arr, person)
          arr["Hon."].nil? ? "#{person.title} #{person.first_name} #{person.last_name}" : "Hon #{person.first_name} #{person.last_name}"
        end

        def format_physical_address(arr)
          "#{arr["electorate_address_1"]}\n#{arr["Electorate Address"]}"
        end

        def format_postal_address(arr)
          "#{arr["postal_address_1"]}\n#{arr["Postal Address"]}"
        end

    end # CSVLower
  end # WA
end # MyRepresentatives
