module MyRepresentatives
  module WA
    class CSVUpper
      include MyRepresentatives::Fileable
      include MyRepresentatives::Guessable

      attr_accessor :xls_url, :xls_filename, :csv_filename, :people

      def initialize
        self.xls_url = "http://www.parliament.wa.gov.au/WebCMS/WebCMS.nsf/resources/file-data-for-legislative-council-members/$file/DATA%20FOR%20LEGISLATIVE%20COUNCIL%20MEMBERS%2023052017.xls"
        self.xls_filename = "tmp/csv_wa_upper.xls"
        self.csv_filename = "tmp/csv_wa_upper.csv"
        self.people = []

        csv_from_url
        people_from_csv
      end

      private

        def csv_from_url
          create_tmp

          open(@xls_filename, "wb") do |file|
            open(@xls_url) do |uri|
               file.write(uri.read)
            end
          end

          excel = Excel2CSV.read(@xls_filename)
          CSV.open(@csv_filename, "wb") do |csv|
            excel.each_with_index do |row, index|

              if index == 0  # This exists to fix newlines in header row
                new_row = []

                row.each do |col|
                  col.gsub!("\n","")
                  new_row << col
                end
                csv << new_row
              else
                csv << row
              end
            end
          end
          FileUtils.rm_r(@xls_filename)
        end

        def people_from_csv
          CSV.foreach(@csv_filename, headers: true) do |row|

            if row["FIRST_NAME"] && row["SURNAME"] && row["REGION"] # Fix for blank rows

              # Setup the electorate
              electorate_name = find_electorate(row)
              electorate      = Electorate.new(electorate_name)
              electorate.state_wa_upper!

              # Setup the Representative (Person)
              person = Person.new(electorate)

              person.title                      = find_title(row)
              person.first_name                 = find_first_name(row)
              person.last_name                  = find_last_name(row)
              person.preferred_name             = find_preferred_name(row)
              person.email                      = find_email(row)
              person.phone                      = find_phone(row)
              person.party_name                 = find_party(row)
              person.physical_address           = find_physical_address(row)
              person.postal_address             = find_postal_address(row)
              person.gender                     = guess_gender(row["Title"])
              person.formal_name                = format_formal_name(row,person)
              person.honorifics                 = "MLC"
              person.salutation                 = nil
              person.image_url                  = nil
              person.homepage_url               = nil

              @people << person

            end
          end
        end

        def find_first_name(arr)
          arr["FIRST_NAME"]
        end

        def find_last_name(arr)
          arr["SURNAME"]
        end

        def find_preferred_name(arr)
          arr["PREFERRED_NAME"]
        end

        def find_title(arr)
          arr["HON"].nil? ? arr["TITLE"] : "Hon"
        end

        def find_electorate(arr)
          arr["REGION"]
        end

        def find_email(arr)
          nil
        end

        def find_party(arr)
          arr["PARTY"]
        end

        def find_phone(arr)
          nil
        end

        def format_formal_name(arr, person)
          arr["HON"].nil? ? "#{person.title} #{person.first_name} #{person.last_name}" : "Hon #{person.first_name} #{person.last_name}"
        end

        def find_physical_address(arr)
          arr["ELEC_ADDRESS"]
        end

        def find_postal_address(arr)
          arr["ELEC_ADDRESS_MAILING"]
        end

    end # CSVUpper
  end # WA
end # MyRepresentatives
