module MyRepresentatives
  module WA
    class WebShow
      include MyRepresentatives::Guessable

      attr_accessor :url, :document, :logger

      def initialize(url)
        @logger = Logger.new(STDOUT)
        raise MyRepresentatives::InvalidURLError unless url && url.is_a?(String)
        @url = url
        fetch_document
        raise MyRepresentatives::NokogiriDocumentPropertiesError unless test_document_for_validity
      end

      def homepage_url
        @url
      end

      def formal_name
        begin
          @document.css("div#content").css("font")[0].text
        rescue NoMethodError
          nil
        end
      end

      def title
        begin
          guess_title(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def first_name
        begin
          guess_first(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def last_name
        begin
          guess_last(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def preferred_name
        begin
          guess_preferred(formal_name)
        rescue NoMethodError
          nil
        end
      end

      def electorate_name
        begin
          regex = /Electorate:(.+?)Inaugural/
          alt_regex = /Electorate:(.+?)Speeches/

          text = @document.css("font[size='2']").text.strip
          match = text.match(regex)
          alt_match = text.match(alt_regex)

          if match
            match[1]
          elsif alt_match
            alt_match[1]
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def party_name
        begin
          regex = /Party:(.+?)Electorate/
          alt_regex = /Party:(.+?)Inaugural/

          text = @document.css("font[size='2']").text.strip
          match = text.match(regex)
          alt_match = text.match(alt_regex)

          if match
            match[1]
          elsif alt_match
            alt_match[1]
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def email
        begin
          regex = /Email:\s(.+?wa.gov.au)/

          text = @document.css("font[size='2']").text.strip
          match = text.match(regex)

          if match
            match[1]
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      def image_url
        begin
          uri = nil
          @document.css("div#content").css("img").each do |img|
            link = img.attr("src")
            uri = link if link.include?('(MemberPics)')
            break if link.include?('(MemberPics)')
          end

          if uri
            "http://www.parliament.wa.gov.au/Parliament/Memblist.nsf/#{uri.gsub("../","")}"
          else
            nil
          end

        rescue
          nil
        end
      end

      def phone
        begin
          regex1 = /Ph:\s([0-9]{4} [0-9]{4})Email/
          regex2 = /Ph:\s(08 [0-9]{4} [0-9]{4})Email/
          regex3 = /Ph:\s([0-9]{4} [0-9]{3} [0-9]{3})Email/
          regex4 = /Ph:\s(.+?)$/
          regex5 = /Ph:\s(.+?)Email/m

          text = @document.css("font[size='2']").text.strip
          match1 = text.match(regex1)
          match2 = text.match(regex2)
          match3 = text.match(regex3)
          match4 = text.match(regex4)
          match5 = text.match(regex5)

          if match1
            match = match1[1].gsub(/\D/, '')
            match.start_with?("08") ? match : "08"+match
          elsif match2
            match = match2[1].gsub(/\D/, '')
            match.start_with?("08") ? match : "08"+match
          elsif match3
            match = match1[3].gsub(/\D/, '')
            match3
          elsif match4
            match = match4[1].gsub(/\D/, '')
            match.start_with?("08") ? match : "08"+match
          elsif match5
            match = match5[1].gsub(/\D/, '')
            match.start_with?("08") ? match : "08"+match
          else
            nil
          end
        rescue NoMethodError
          nil
        end
      end

      private

        def fetch_document
          begin
            request   = open(@url)
            @document = Nokogiri::HTML(request)
          rescue => err
            @logger.debug("Failed to connect to the url: #{@url}")
            raise err
          end
        end

        def test_document_for_validity
          true
        end

    end # WebShow
  end # WA
end # MyRepresentatives
